#[non_exhaustive]pub struct DiscoverExchange<'a> {
pub request: Option<(u64, Option<&'a Value>)>,
pub result: Option<(u64, &'a Value)>,
pub error: Option<u64>,
}Expand description
The observed server/discover exchange — the optional stateless capability/identity
probe — when present. A session is valid with no discovery at all.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.request: Option<(u64, Option<&'a Value>)>The server/discover request: its event seq and params value (if any).
result: Option<(u64, &'a Value)>The successful server/discover result: its event seq and result value.
error: Option<u64>The seq of an error response to the server/discover request.