#[non_exhaustive]pub struct Finding {
pub check: String,
pub seq: Option<u64>,
pub detail: String,
}Expand description
One concrete violation, addressed to a requirement and (where possible) an event.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.check: StringThe validator check that produced this finding.
seq: Option<u64>The event seq the finding points at, when one event is identifiable.
detail: StringWhat was observed and what was expected, in one actionable sentence.